==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Effect/stereo/translations/stereo_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="31"/>
        <source>Extra Stereo Plugin</source>
        <translation>Plugin Stereo Extra</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>About Extra Stereo Plugin</source>
        <translation>Tentang Plugin Stereo Extra</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>Plugin Stereo Extra Qmmp</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="54"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>Berdasarkan pada Plugin Stereo Extra untuk Xmms oleh Johan Levin</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>Setelan Plugin Stereo Extra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>Intensitas efek:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Effect/stereo/translations/stereo_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="31"/>
        <source>Extra Stereo Plugin</source>
        <translation>Plugin Stereo Extra</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>About Extra Stereo Plugin</source>
        <translation>Tentang Plugin Stereo Extra</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>Plugin Stereo Extra Qmmp</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="54"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>Berdasarkan pada Plugin Stereo Extra untuk Xmms oleh Johan Levin</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>Setelan Plugin Stereo Extra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>Intensitas efek:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
